<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>picostk :: {% block title %}{% endblock %}</title>
    {% load staticfiles %}
    {% load bootstrap3 %}

    <!-- Bootstrap -->    
    {% bootstrap_css %}
    <link href="{% static "pstk.css"%}" media="screen" rel="stylesheet">
    <!-- HTML5 Shim and Respond.js IE8 support of HTML5 elements and media queries -->
    <!-- WARNING: Respond.js doesn't work if you view the page via file:// -->
    <!--[if lt IE 9]>
      <script src="https://oss.maxcdn.com/libs/html5shiv/3.7.0/html5shiv.js"></script>
      <script src="https://oss.maxcdn.com/libs/respond.js/1.4.2/respond.min.js"></script>
    <![endif]-->
  </head>
  <body>
    {# Display django.contrib.messages as Bootstrap alerts #}    
    {% bootstrap_messages %}

    {% include "header.html" %}
    
    {% block content %}
    {% endblock %}
      
    {# Load JS #}
    <!-- jQuery (necessary for Bootstrap's JavaScript plugins) -->
    <script src="{% static "bower_components/jquery/dist/jquery.min.js" %}"></script>
    <script src="{% static "bower_components/bootstrap/js/tooltip.js" %}"></script>
    <script src="{% static "bower_components/bootstrap/js/popover.js" %}"></script>
    <script type="text/javascript"> <!--
      jQuery( document ).ready(function( $ ) {
        // $("[data-toggle='tooltip']").tooltip();
        $("[data-toggle='popover']").popover({
          container: 'body'
        });
      });
    -->
    </script>
    {% bootstrap_javascript %}    
    {% block bottomjs %}     
    {% endblock %}
  </body>
</html>
