{% load staticfiles %}
{% load picostack_tags %}
<nav class="navbar navbar-default" role="navigation">
  <div class="container-fluid">
    <!-- Brand and toggle get grouped for better mobile display -->
    <div class="navbar-header">
      <button type="button" class="navbar-toggle" data-toggle="collapse" data-target="#bs-example-navbar-collapse-1">
        <span class="sr-only">Toggle navigation</span>
        <span class="icon-bar"></span>
        <span class="icon-bar"></span>
        <span class="icon-bar"></span>
      </button>
      <a class="navbar-brand" style="font-family: monospace;" href="#"><img src="{% static "i/picostk.svg"%}" style="margin-right: 10px; margin-top: -3px;"><strong>picostack</strong></a>
    </div>

    <!-- Collect the nav links, forms, and other content for toggling -->
    <div class="collapse navbar-collapse" id="bs-example-navbar-collapse-1">
      <ul class="nav navbar-nav">
        <li class="active"><a href="/instances">Instances</a></li>
      </ul>
      <ul class="nav navbar-nav navbar-right">
        <li><a href="/logout">Logout</a></li>
        <li><a href="/admin">Admin</a></li>
        <li class="dropdown">
          <a href="#" class="dropdown-toggle" data-toggle="dropdown">Help<b class="caret"></b></a>
          <ul class="dropdown-menu">
            <li><a href="https://github.com/ewiger/picostack">GitHub</a></li>
            <li><a href="#aboutModal" data-toggle="modal" data-target="#aboutModal">About</a></li>
          </ul>
        </li>
      </ul>
    </div><!-- /.navbar-collapse -->
  </div><!-- /.container-fluid -->
</nav>

<div class="modal fade" id="aboutModal">
  <div class="modal-dialog">
    <div class="modal-content">
      <div class="modal-header">
        <button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times;</button>
        <h4 class="modal-title">About picostack</h4>
      </div>
      <div class="modal-body">
        <h4>You are running <a href="https://github.com/ewiger/picostack">picostack</a> version <strong>{% picostack_version %}</strong></h4>
        <p>A super lightweight KVM virtualization manager, suitable for single linux-based host system. </p>
        <p>Note that <a href="https://github.com/ewiger/picostack">picostack</a> is not designed to provide cloud service, but to be used on top of a single server appliance. It can be put to run on powerful high-end machines with a lot of RAM and CPU resources, that can be split and virtualized into kvm boxes. It has a django-based interface and a daemon that does the main work like taking care of and running VM instances in the background. Such approach can smooth the transition to the cloud technology.</p>
        <hr />
<p>Copyright &copy; 2014 Yauhen Yakimovich</p>
<p>Licensed under the MIT License (MIT). Read a copy of LICENSE distributed with this code.</>
      </div>
      <div class="modal-footer">
        <button type="button" class="btn btn-default" data-dismiss="modal">Close</button>        
      </div>
    </div><!-- /.modal-content -->
  </div><!-- /.modal-dialog -->
</div><!-- /.modal -->
